<?php declare(strict_types=1);

namespace Drupal\config_patch_github_api\Github;

use Drupal\config_patch_github_api\Exception\MissingCredentialsException;
use Drupal\config_patch_github_api\Form\ConfigPatchGithubApiCredentialsForm;
use Drupal\Core\State\StateInterface;
use Github\Client;

class ConfigPatchGithubClientFactory {

  /**
   * @var \Drupal\Core\State\StateInterface
   */
  private $state;

  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  public function create(array $settings = []): ConfigPatchGithubClient {
    $settings = empty($settings) ? $this->getSavedSettings() : $settings;
    $github_client = new Client();
    $github_client->setUrl($settings['url']);
    $github_client->authenticate($settings['token'], Client::AUTH_HTTP_TOKEN);
    return new ConfigPatchGithubClient($github_client);
  }

  private function getSavedSettings(): array {
    $settings = $this->state->get(ConfigPatchGithubApiCredentialsForm::SETTINGS, []);
    $this->validateSettings($settings);
    return $settings;
  }

  private function validateSettings(array $settings): void {
    if (empty($settings['url'])) {
      throw new MissingCredentialsException('The Github url is not defined.');
    }
    if (empty($settings['token'])) {
      throw new MissingCredentialsException('The Github token is not defined.');
    }
  }

}
